@@ -7,15 +7,11 @@ group <- ifelse(iris[keep, "Species"] == "setosa", "A", "B")
 
 ## ---- message = FALSE----------------------------------------------------
 pd.nn <- propd(counts, group, weighted = FALSE)
-pd.wn <- propd(counts, group, weighted = TRUE)
-pd.na <- propd(counts, group, weighted = FALSE, alpha = .01)
-pd.wa <- propd(counts, group, weighted = TRUE, alpha = .01)
 
-## ---- message = FALSE----------------------------------------------------
-pd.nn <- propd(counts, group, weighted = FALSE)
-pd.wn <- propd(counts, group, weighted = TRUE)
-pd.na <- propd(counts, group, weighted = FALSE, alpha = .01)
-pd.wa <- propd(counts, group, weighted = TRUE, alpha = .01)
+## ---- message = FALSE, eval = FALSE--------------------------------------
+#  pd.wn <- propd(counts, group, weighted = TRUE)
+#  pd.na <- propd(counts, group, weighted = FALSE, alpha = .01)
+#  pd.wa <- propd(counts, group, weighted = TRUE, alpha = .01)
 
 ## ---- message = FALSE, eval = FALSE--------------------------------------
 #  pd.nn <- updateF(pd.nn, moderated = FALSE)
